Introduction
============


``ftw.globalstatusmessage`` displays a global static plone-like statusmessage.
Configurable throught the plone control panel.

Currently 3 types are supported:

- info (green)
- warning (orange)
- error (red)



Links
=====

- Main github project repository: https://github.com/4teamwork/ftw.globalstatusmessage
- Issue tracker: https://github.com/4teamwork/ftw.globalstatusmessage/issues
- Package on pypi: http://pypi.python.org/pypi/ftw.globalstatusmessage
- Continuous integration: https://jenkins.4teamwork.ch/search?q=ftw.globalstatusmessage


Copyright
=========

This package is copyright by `4teamwork <http://www.4teamwork.ch/>`_.

``ftw.tooltip`` is licensed under GNU General Public License, version 2.


